@@ -1,29 +1,26 @@
+# -*- coding: utf-8 -*-
 """
 Handles instrument specific info for the HARPS spectrograph
 
 Mostly reading data from the header
 """
-import os.path
-import glob
 import logging
-from datetime import datetime
-import fnmatch
-import json
+import os.path
 
 import numpy as np
-from astropy.io import fits
 from astropy import units as q
+from astropy.io import fits
 from astropy.time import Time
 from dateutil import parser
 
-from .common import getter, Instrument, observation_date_to_night
+from .common import Instrument, getter, observation_date_to_night
 
 logger = logging.getLogger(__name__)
 
 
 class JWST_NIRISS(Instrument):
     def add_header_info(self, header, mode, **kwargs):
-        """ read data from header and add it as REDUCE keyword back to the header """
+        """read data from header and add it as REDUCE keyword back to the header"""
         # "Normal" stuff is handled by the general version, specific changes to values happen here
         # alternatively you can implement all of it here, whatever works
         header = super().add_header_info(header, mode)
@@ -80,7 +77,13 @@ class JWST_NIRISS(Instrument):
         return files
 
     def sort_files(self, input_dir, target, night, mode, allow_calibration_only=False):
-        files = super().sort_files(input_dir, target, night, mode, allow_calibration_only=allow_calibration_only)
+        files = super().sort_files(
+            input_dir,
+            target,
+            night,
+            mode,
+            allow_calibration_only=allow_calibration_only,
+        )
         for i, (k, file) in enumerate(files):
             files_split = []
             for f in file["science"]:
@@ -89,7 +92,7 @@ class JWST_NIRISS(Instrument):
         return files
 
     def get_wavecal_filename(self, header, mode, **kwargs):
-        """ Get the filename of the wavelength calibration config file """
+        """Get the filename of the wavelength calibration config file"""
         cwd = os.path.dirname(__file__)
         fname = "{instrument}_{mode}_2D.npz".format(instrument="harps", mode=mode)
         fname = os.path.join(cwd, "..", "wavecal", fname)
