@@ -1,25 +1,24 @@
+# -*- coding: utf-8 -*-
 """
 Handles instrument specific info for the UVES spectrograph
 
 Mostly reading data from the header
 """
-import os.path
-import glob
 import logging
-from datetime import datetime
+import os.path
 
 import numpy as np
 from astropy.io import fits
 from dateutil import parser
 
-from .common import getter, Instrument, observation_date_to_night
+from .common import Instrument, getter, observation_date_to_night
 
 logger = logging.getLogger(__name__)
 
 
 class UVES(Instrument):
     def add_header_info(self, header, mode, **kwargs):
-        """ read data from header and add it as REDUCE keyword back to the header """
+        """read data from header and add it as REDUCE keyword back to the header"""
         # "Normal" stuff is handled by the general version, specific changes to values happen here
         # alternatively you can implement all of it here, whatever works
         header = super().add_header_info(header, mode)
@@ -31,7 +30,7 @@ class UVES(Instrument):
         return header
 
     def get_wavecal_filename(self, header, mode, **kwargs):
-        """ Get the filename of the wavelength calibration config file """
+        """Get the filename of the wavelength calibration config file"""
         info = self.load_info()
         specifier = int(header[info["wavecal_specifier"]])
 
@@ -41,3 +40,11 @@ class UVES(Instrument):
         )
         fname = os.path.join(cwd, "..", "wavecal", fname)
         return fname
+
+    def get_mask_filename(self, mode, **kwargs):
+        i = self.name.lower()
+        m = mode.lower()
+        fname = f"mask_{i}_{m}.fits.gz"
+        cwd = os.path.dirname(__file__)
+        fname = os.path.join(cwd, "..", "masks", fname)
+        return fname
