@@ -1,7 +1,9 @@
-import pytest
+# -*- coding: utf-8 -*-
 import numpy as np
+import pytest
+
+from pyreduce.continuum_normalization import continuum_normalize, splice_orders
 
-from pyreduce.continuum_normalization import splice_orders, continuum_normalize
 
 @pytest.fixture
 def spliced(spec, wave, normflat):
@@ -17,6 +19,7 @@ def spliced(spec, wave, normflat):
     )
     return spec, wave, blaze, sigma
 
+
 def test_splice(spec, wave, normflat, order_range):
     spec, sigma = spec
     norm, blaze = normflat
@@ -50,9 +53,10 @@ def test_splice(spec, wave, normflat, order_range):
         == norm.shape[1]
     )
 
+
 def test_continuum(spliced):
     spec, wave, cont, sigm = spliced
-    
+
     if wave is None:
         pytest.skip("Need wavecal for continuum")
 
